[Logo Design] [Javascript] [User Interface/IA] [Graphic Design] [Website Design]

I'm preparing to launch a website, www.recapturedocs.com. It is a web site designed to take scanned documents in PDF form, separate them out into individual pages, and have each page retyped by a human typist.

The current site is live, but there is also a demo site at http://www.recapturedocs.com:8080/ which you may use to walk through the process and see the service in action. You may create jobs on that site that you must service yourself. When you pay for a job via the demo site, you must have an amazon.com account to "make the payment", though your credit card will not be charged (you can note that the address and last four digits of the credit card number are fake when confirming the payment). After you make the payment, the site will give you links to complete the job yourself.

You must have walked through the process before bidding. If you encounter any problems walking through the process, please don't hesitate to describe the problem so I can correct it and you can make an informed bid.

As you'll see when you go through it, the site is functional. A skeleton of content is there, but what I need is a compelling design for the site. I'm looking for something clean, simple, and classy. Deliverables must include the following:

1. A master site design template on which the application will reside. Many of the pages will use this template. This template should be XHTML and CSS (and possibly Javascript). The template should include a banner and two menus (one for main application functions and another for auxiliary pages, such as "contact us" and "privacy policy").

2. The master template should include a compelling logo related to the service (document retyping). The logo must include the original vector image (preferred) or high-resolution raster image.

3. One page design, the home page (based on the master template). The home page should include (inline, or link, or popup) a visualization of what the project is about. The visualization could be an intro video or static image or animated cartoon. Use your imagination here, but try to keep it classy. Finally, the home page should include a friendly, preferably animated form to upload the document and get started. I imagine the upload form to overlay the main content after the user clicks a "Get Started" button.

5. All pages should use well-structured XHTML and CSS and cross-browser javascript (must run on IE9, FF 3.5, and Chrome). jQuery is preferred for scripting. If another library is to be considered, you must provide a compelling reason why it should be used and I must approve the decision before accepting the bid. Provider is encouraged to use modern standards including HTML5 and web fonts. Provider is discouraged from using old techniques such as using images for buttons and rounded-corners.

The project will be split into three equal milestones.

1. In the first milestone, the provider will clarify any questions and provide a complete but draft deliverable of all components.

2. I will give feedback and the provider will make minor adjustments and provide a final draft of all deliverable components.

3. The final milestone is reserved for integration support and unforseen work such as necessary additional pages, enhancements, or tweaks within the general scope outlined above. This milestone will be complete when the deliverable has been sucessfully integrated with the existing application.

Please supply portfolio references for similar work that includes site design, some dynamic behavior, and logo design.
